import { PageParams } from "../base/BaseDataModel";

/**
 * 客户费用申请审批参数
 */
export interface CustomerFeeApprovalRecordDto {
    /**
     * 费用编号
     *
     * @mbg.generated
     */
    feeId: string;

    /**
     * 费用名称
     *
     * @mbg.generated
     */
    feeSetName: string;

    /**
     * 产品编号
     *
     * @mbg.generated
     */
    productId: string;

    /**
     * 产品名称
     *
     * @mbg.generated
     */
    productName: string;

    /**
     * 分组名称
     *
     * @mbg.generated
     */
    groupName: string;

    /**
     * 作业机构名称
     *
     * @mbg.generated
     */
    orgName: string;

    /**
     * 客户名称
     *
     * @mbg.generated
     */
    customerName: string;

    /**
     * 费用类型名称
     *
     * @mbg.generated
     */
    feeSetTypeName: string;

    /**
     * 生效起始时间
     *
     * @mbg.generated
     */
    beginDate: string | Date;

    /**
     * 生效结束时间
     *
     * @mbg.generated
     */
    endDate: string | Date;
}

/**
 * 客户费用审批查询参数
 */
export interface CustomerFeeApprovalRecordParam extends PageParams {
    /**
     * 编号
     *
     * @mbg.generated
     */
    id?: number;
    /**
     * 业务员编号
     *
     * @mbg.generated
     */
    salesmanId?: number;

    /**
     * 费用编号
     *
     * @mbg.generated
     */
    feeId?: string;

    /**
     * 产品编号
     *
     * @mbg.generated
     */
    productId?: string;

    /**
     * 创建人编号
     *
     * @mbg.generated
     */
    createUserId?: number;

    /**
     * 审批人员编号
     *
     * @mbg.generated
     */
    approvalUserId?: number;

    /**
     * 起始时间
     */
    beginDate?: string | Date;

    /**
     * 结束时间
     */
    endDate?: string | Date;
}

/**
 * 客户费用审批记录
 */
export interface CustomerFeeApprovalRecordListDto extends CustomerFeeApprovalRecordDto {
    /**
     * 编号  （不填）
     *
     * @mbg.generated
     */
    id: number;

    /**
     * 业务员编号 （不填）
     *
     * @mbg.generated
     */
    salesmanId: number;

    /**
     * 业务员名称 （不填）
     */
    salesmanName: string;

    /**
     * 创建人编号  （不填）
     *
     * @mbg.generated
     */
    createUserId: number;

    /**
     * 创建人名 （不填）
     *
     * @mbg.generated
     */
    createUserName: string;

    /**
     * 创建时间 （不填）
     *
     * @mbg.generated
     */
    createTime: string | Date;

    /**
     * 当前审批人员名称  （不填）
     *
     * @mbg.generated
     */
    approvalUserName: string;

    /**
     * 当前审批状态 （不填）
     *
     * @mbg.generated
     */
    feeApprovalStatus: number;

    /**
     * 当前审批状态 （不填）
     *
     * @mbg.generated
     */
    feeApprovalStatusName: string;

    /**
     * 当前审批时间 （不填）
     *
     * @mbg.generated
     */
    approvalTimeStr: string;

    /**
     * 审批状态  （不填）
     */
    customerFeeApprovalStatusDtoList: CustomerFeeApprovalStatusDto[];
}

/**
 * 客户费用审批状态参数
 */
export interface CustomerFeeApprovalStatusDto {
    /**
     * 编号
     *
     * @mbg.generated
     */
    id?: number;

    /**
     * 审批记录编号
     *
     * @mbg.generated
     */
    approvalRecordId: number | undefined;

    /**
     * 审批人员编号
     *
     * @mbg.generated
     */
    approvalUserId: number | undefined;

    /**
     * 审批人员名称
     *
     * @mbg.generated
     */
    approvalUserName: string | undefined;

    /**
     * 序号
     *
     * @mbg.generated
     */
    orderNumber: number | undefined;

    /**
     * 审批状态
     *
     * @mbg.generated
     */
    feeApprovalStatus: number | undefined;

    /**
     * 创建时间
     *
     * @mbg.generated
     */
    createTime?: string | Date;

    /**
     * 审批时间
     *
     * @mbg.generated
     */
    approvalTime?: string | Date;

    /**
     * 备注
     *
     * @mbg.generated
     */
    remark: string;

}

/**
 * 客户费用界面查看审批结果参数
 */
export interface CustomerFeeApprovalStatusParam {
    /**
     * 费用编号
     *
     * @mbg.generated
     */
    feeId: string;

    /**
     * 审批记录编号 废弃
     *
     * @mbg.generated
     */
    // approvalRecordId: number;

}
