import { PageParams } from "@/api/base/BaseDataModel";

/**
 * 财务应付明细参数
 */
export interface FinancialBillDetailParam extends PageParams {
    /**
     * 编号
     */
    id?: number;

    /**
     * 主单编号
     */
    summaryId?: number;

    /**
     * 费项类型
     */
    feeItemCategoryId?: number;

    /**
     * 主体
     */
    stakeholder?: number;

    /**
     * 渠道商
     */
    providerId?: number;

    /**
     * 账单时间
     */
    billTime?: string;

    /**
     * 单号类型
     */
    billCodeType?: number;

    /**
     * 单号
     */
    billCode?: string;
}

/**
 * 财务账单明细
 */
export interface FinancialBillDetailDto {
    /**
     * 编号
     */
    id?: number;

    /**
     * 主单编号
     */
    summaryId?: number;

    /**
     * 费项类型
     */
    feeItemCategoryId?: number | string;

    /**
     * 主体
     */
    stakeholder?: number;

    /**
     * 渠道商
     */
    providerId?: number | string;

    /**
     * 账单时间
     */
    billTime?: string;

    /**
     * 航司名称
     */
    airlinesId?: number;

    /**
     * 运单号(提单号)
     */
    waybillNumber?: string;

    /**
     * 提单录入的各费项，逗号隔开
     */
    referFeeItemCategory?: string;

    /**
     * 内部单号
     */
    orderId?: string;

    /**
     * 尾程单号
     */
    trackingId?: string;

    /**
     * 邮编
     */
    zipCode?: string;

    /**
     * 区间名称
     */
    partitionName?: string;

    /**
     * 重量
     */
    weight?: number;

    /**
     * 计费重量
     */
    countFeeWeight?: number;

    /**
     * 重量单位
     */
    calculateUnit?: number | string;

    /**
     * 件数
     */
    orderPieces?: number;

    /**
     * 体积
     */
    volume?: number;

    /**
     * 长
     */
    length?: number;

    /**
     * 宽
     */
    width?: number;

    /**
     * 高
     */
    height?: number;

    /**
     * 费用类型
     */
    feeItemId?: number;

    /**
     * 费用类型名称
     */
    feeItemName?: string;

    /**
     * 国家/地区
     *
     * @mbg.generated
     */
    countryId?: number | string;

    /**
     * 国家/地区
     */
    countryName?: string;

    /**
     * 始发港
     *
     * @mbg.generated
     */
    departurePort?: number | string;

    /**
     * 始发港
     */
    departurePortName?: string;

    /**
     * 目的港
     *
     * @mbg.generated
     */
    destinationPort?: number | string;

    /**
     * 目的港
     */
    destinationPortName?: string;

    /**
     * 名称后缀
     */
    feeTypeNamePostfix?: string;

    /**
     * 币种
     */
    currencyCode?: string;

    /**
     * 单价
     */
    offerPrice?: number;

    /**
     * 原始费用
     */
    originalFee?: number;

    /**
     * 汇率
     */
    exchangeRate?: number;

    /**
     * 汇率版本
     */
    rateVersion?: string;

    /**
     * 费用
     */
    fee?: number;

    /**
     * 分摊方式
     */
    shareType?: number;

    /**
     * 分组分摊方式
     */
    groupShareType?: number | string;

    /**
     * 分组编码
     */
    groupCode?: string;

    /**
     * 状态 0: 新增 1:对账 2: 分摊 3:关账
     */
    billDetailState?: number;

    /**
     * 备注
     */
    remark?: string

    /**
     * 地址
     */
    address?: string
}