import { PageParams } from "../base/BaseDataModel";

/**
 * 分公司利润明细查询参数
 */
export interface BranchProfitDetailParam extends PageParams {
    /**
     * 订单编号
     *
     * @mbg.generated
     */
    orderId?: string;


    /**
     * 起始时间
     *
     * @mbg.generated
     */
    beginDate?: string;

    /**
     * 结束时间
     *
     * @mbg.generated
     */
    endDate?: string;

    /**
     * 产品编号
     *
     * @mbg.generated
     */
    productId?: string;


    /**
     * 客户编号
     *
     * @mbg.generated
     */
    customerId?: number;

    /**
     * 客户编号
     */
    customerIdList?: number[];

    /**
     * 分公司编号
     *
     * @mbg.generated
     */
    orgId?: string;


    /**
     * 业务员编号
     *
     * @mbg.generated
     */
    salesmanId?: number;

    /**
     * 订单编号
     *
     * @mbg.generated
     */
    orderIdList?: string[];

    /**
     * 数据类型 0 正常数据 1异常数据
     *
     * @mbg.generated
     */
    dataType: 0 | 1;

    reportQueryDateType?: number//查询日期类型 1 收货时间 0 生成时间

    /**
     * 盈利状态
     */
    profitStatus?: number
}

/**
 * 分公司利润明细
 */
export interface BranchProfitDetailDto {
    /**
     * 订单编号
     *
     * @mbg.generated
     */
    orderId: string;

    /**
     * 跟踪号
     *
     * @mbg.generated
     */
    trackingNumber: string;

    /**
     * 转单号
     *
     * @mbg.generated
     */
    transferNumber: string;

    /**
     * 订单件数
     *
     * @mbg.generated
     */
    orderPieces: number;

    /**
     * 收货时间
     *
     * @mbg.generated
     */
    receiveTime: string;

    /**
     * 产品编号
     *
     * @mbg.generated
     */
    productId: string;

    /**
     * 产品名称
     *
     * @mbg.generated
     */
    productName: string;

    /**
     * 派送渠道
     *
     * @mbg.generated
     */
    deliveryChannel: string;

    /**
     * 客户编号
     *
     * @mbg.generated
     */
    customerId: number;

    /**
     * 客户编号
     *
     * @mbg.generated
     */
    customerName: string;

    /**
     * 分公司编号
     *
     * @mbg.generated
     */
    orgId: string;

    /**
     * 分公司编号
     *
     * @mbg.generated
     */
    orgName: string;

    /**
     * 业务员名称
     *
     * @mbg.generated
     */
    salesmanName: string;

    /**
     * 业务员编号
     *
     * @mbg.generated
     */
    salesmanId: number;

    /**
     * 客户总收入
     *
     * @mbg.generated
     */
    customerRevenue: number;

    /**
     * 计费重量
     *
     * @mbg.generated
     */
    customerCountFeeWeight: number;

    /**
     * 费用
     *
     * @mbg.generated
     */
    customerFreightFee: number;

    /**
     * 客户附加费
     *
     * @mbg.generated
     */
    customerSurcharge: number;

    /**
     * 客户税费
     *
     * @mbg.generated
     */
    customerTaxFee: number;

    /**
     * 客户杂费
     *
     * @mbg.generated
     */
    customerSundryFees: number;

    /**
     * 客户偏远费
     *
     * @mbg.generated
     */
    customerRemoteFees: number;

    /**
     * 客户费用版本
     *
     * @mbg.generated
     */
    customerFeeVersion: string;

    /**
     * 分公司总费用
     *
     * @mbg.generated
     */
    orgFeeAmount: number;

    /**
     * 计费重量
     *
     * @mbg.generated
     */
    orgCountFeeWeight: number;

    /**
     * 费用
     *
     * @mbg.generated
     */
    orgFreightFee: number;

    /**
     * 分公司附加费
     *
     * @mbg.generated
     */
    orgSurcharge: number;

    /**
     * 分公司税费
     *
     * @mbg.generated
     */
    orgTaxFee: number;

    /**
     * 分公司杂费
     *
     * @mbg.generated
     */
    orgSundryFees: number;

    /**
     * 分公司偏远费
     *
     * @mbg.generated
     */
    orgRemoteFees: number;

    /**
     * 分公司费用版本
     *
     * @mbg.generated
     */
    orgFeeVersion: string;

    /**
     * 销售承担费用
     *
     * @mbg.generated
     */
    salesAmount: number;

    /**
     * 利润
     *
     * @mbg.generated
     */
    profit: number;

    /**
     * 创建时间
     *
     * @mbg.generated
     */
    createTime: string;

    /**
     * 业务类型
     *
     * @mbg.generated
     */
    businessType: number;

    /**
     * 备注
     *
     * @mbg.generated
     */
    remark: string;

    /**
     * 数据类型 0 正常数据 1异常数据
     *
     * @mbg.generated
     */
    dataType: number;

    /**
     * 国家编号
     *
     * @mbg.generated
     */
    countryCode: string;

    /**
     * 国家名称
     *
     * @mbg.generated
     */
    countryName: string;
}
